#!/usr/bin/gnuplot

set colors classic

set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set ytics 10
set xtics 10
set mytics 10
set mxtics 10
set tics format "%T"
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.3 font "Helvetica,14"

set arrow from 1,graph 0 rto 0,graph 1 nohead lt 0

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#cccccc' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 50,1e5 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 0.8

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

x1=0.2
x2=5
y1=1.e5
y2=1.e7

p \
  "<./hc_sfd.awk sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\
  "<./hc_sfd.awk sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/1100.out | ./hc.awk" u 1:2 w l ls 1 t "evolved MB",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/1100.out | ./hc.awk" u 1:2 w l ls 2 t "evolved Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\

pa -1

set term postscript eps enh color solid "Helvetica" 18 size 9cm,9cm
set out "sfd_1100.eps"
rep

system("eps2png sfd_1100.eps")

q


  "box.dat" u (x1+$1*(x2-x1)):(y1+$2*(y2-y1)) not w l lt 0,\
  "<awk '(FNR==1){ print \"\"; } ($2==3)' ../*[0-9]*/tmp/0150.out | ./hc.awk" u 1:2 t "evolved NEA"    w l ls 3,\
  "../dat/Harris_etal_2015.dat"  u (10.**$1):(10.**$2) not w p lc rgb '#ffffff' pt 7 ps 1.0,\
  "../dat/Harris_etal_2015.dat"  u (10.**$1):(10.**$2) t "{/=14 Harris etal. (2015)}" w p ls 6,\

tmp=1; set arrow from tmp,graph 0 to tmp,graph 1 nohead lt 0
tmp=1.e6; set arrow from graph 0,first tmp to graph 1,first tmp nohead lt 0

set label "{/Helvetica-Bold=24 MB}" at 50,1e5 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 NEA}" at 0.1,500 center tc rgb '#888888'

#  "../src/MB_2018.dat_hc" u 1:2 t "observed MB" w l ls 5 lw 2,\
#  "../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2) t "Gladman etal. (2009)" w l ls 5 dt 2,\
#  "../dat/Cibulkova_etal_2014_MB.dat_hc" u 1:2 t "Cibulkova etal. (2014)" w l ls 5,\
#  "<./hc_sfd.awk sfd3.dat_EDITED" u 1:2 t "initial NEA"    w l  ls 4,\
#  "<./hc_sfd.awk sfd2.dat_EDITED" u 1:2 t "initial family" w l  ls 4,\
#  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../[0-9]*/tmp/4000.out | ./hc.awk" u 1:2 t "evolved family" w lp ls 2,\



