#!/usr/bin/gnuplot

print "0000"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0000.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 0) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0000.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0000.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0010"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0010.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 10) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0010.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0010.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0020"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0020.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 20) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0020.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0020.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0030"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0030.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 30) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0030.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0030.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0040"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0040.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 40) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0040.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0040.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0050"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0050.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 50) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0050.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0050.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0060"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0060.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 60) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0060.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0060.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0070"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0070.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 70) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0070.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0070.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0080"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0080.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 80) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0080.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0080.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0090"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0090.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 90) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0090.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0090.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0100"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0100.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 100) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0100.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0100.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0110"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0110.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 110) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0110.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0110.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0120"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0120.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 120) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0120.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0120.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0130"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0130.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 130) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0130.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0130.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0140"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0140.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 140) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0140.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0140.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0150"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0150.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 150) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0150.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0150.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0160"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0160.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 160) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0160.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0160.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0170"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0170.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 170) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0170.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0170.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0180"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0180.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 180) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0180.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0180.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0190"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0190.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 190) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0190.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0190.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0200"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0200.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 200) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0200.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0200.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0210"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0210.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 210) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0210.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0210.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0220"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0220.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 220) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0220.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0220.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0230"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0230.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 230) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0230.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0230.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0240"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0240.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 240) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0240.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0240.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0250"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0250.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 250) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0250.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0250.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0260"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0260.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 260) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0260.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0260.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0270"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0270.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 270) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0270.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0270.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0280"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0280.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 280) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0280.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0280.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0290"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0290.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 290) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0290.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0290.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0300"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0300.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 300) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0300.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0300.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0310"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0310.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 310) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0310.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0310.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0320"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0320.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 320) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0320.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0320.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0330"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0330.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 330) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0330.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0330.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0340"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0340.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 340) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0340.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0340.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0350"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0350.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 350) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0350.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0350.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0360"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0360.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 360) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0360.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0360.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0370"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0370.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 370) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0370.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0370.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0380"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0380.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 380) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0380.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0380.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0390"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0390.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 390) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0390.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0390.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0400"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0400.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 400) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0400.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0400.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0410"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0410.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 410) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0410.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0410.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0420"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0420.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 420) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0420.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0420.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0430"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0430.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 430) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0430.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0430.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0440"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0440.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 440) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0440.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0440.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0450"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0450.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 450) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0450.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0450.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0460"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0460.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 460) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0460.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0460.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0470"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0470.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 470) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0470.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0470.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0480"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0480.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 480) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0480.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0480.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0490"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0490.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 490) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0490.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0490.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0500"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0500.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 500) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0500.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0500.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0510"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0510.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 510) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0510.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0510.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0520"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0520.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 520) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0520.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0520.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0530"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0530.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 530) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0530.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0530.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0540"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0540.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 540) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0540.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0540.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0550"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0550.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 550) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0550.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0550.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0560"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0560.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 560) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0560.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0560.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0570"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0570.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 570) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0570.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0570.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0580"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0580.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 580) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0580.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0580.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0590"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0590.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 590) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0590.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0590.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0600"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0600.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 600) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0600.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0600.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0610"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0610.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 610) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0610.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0610.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0620"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0620.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 620) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0620.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0620.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0630"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0630.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 630) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0630.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0630.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0640"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0640.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 640) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0640.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0640.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0650"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0650.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 650) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0650.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0650.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0660"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0660.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 660) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0660.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0660.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0670"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0670.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 670) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0670.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0670.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0680"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0680.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 680) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0680.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0680.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0690"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0690.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 690) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0690.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0690.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0700"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0700.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 700) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0700.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0700.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0710"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0710.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 710) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0710.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0710.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0720"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0720.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 720) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0720.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0720.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0730"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0730.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 730) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0730.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0730.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0740"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0740.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 740) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0740.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0740.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0750"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0750.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 750) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0750.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0750.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0760"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0760.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 760) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0760.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0760.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0770"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0770.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 770) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0770.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0770.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0780"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0780.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 780) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0780.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0780.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0790"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0790.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 790) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0790.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0790.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0800"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0800.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 800) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0800.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0800.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0810"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0810.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 810) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0810.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0810.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0820"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0820.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 820) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0820.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0820.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0830"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0830.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 830) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0830.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0830.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0840"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0840.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 840) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0840.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0840.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0850"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0850.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 850) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0850.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0850.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0860"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0860.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 860) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0860.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0860.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0870"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0870.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 870) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0870.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0870.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0880"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0880.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 880) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0880.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0880.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0890"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0890.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 890) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0890.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0890.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0900"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0900.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 900) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0900.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0900.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0910"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0910.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 910) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0910.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0910.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0920"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0920.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 920) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0920.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0920.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0930"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0930.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 930) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0930.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0930.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0940"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0940.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 940) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0940.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0940.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0950"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0950.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 950) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0950.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0950.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0960"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0960.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 960) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0960.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0960.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0970"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0970.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 970) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0970.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0970.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0980"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0980.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 980) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0980.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0980.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "0990"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_0990.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 990) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0990.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/0990.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "1000"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_1000.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 1000) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/1000.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/1000.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "1010"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_1010.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 1010) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/1010.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/1010.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "1020"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_1020.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 1020) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/1020.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/1020.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "1030"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_1030.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 1030) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/1030.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/1030.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "1040"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_1040.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 1040) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/1040.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/1040.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "1050"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_1050.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 1050) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/1050.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/1050.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "1060"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_1060.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 1060) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/1060.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/1060.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "1070"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_1070.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 1070) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/1070.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/1070.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "1080"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_1080.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 1080) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/1080.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/1080.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "1090"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_1090.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 1090) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/1090.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/1090.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



#!/usr/bin/gnuplot

print "1100"

set colors classic
set term postscript eps enh color solid "Helvetica" 18 size 9cm,9.25cm
set out "eps/sfd_1100.eps"

set tit sprintf("{/Helvetica-Oblique t} = %5.1f My", 1100) offset 0,-0.5
set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of bodies, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.7*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "%T"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set lmargin 6.5
set rmargin 0.5
set bmargin 3.2
set tmargin 1.6

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#ffaa00' lw 2 pt 1		# evolved Vesta
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set label "{/Helvetica-Bold=24 MB}" at 7,1e7 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 Vesta}" at 0.10,1000 center tc rgb '#ffaa00'

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (1.2e4) * (x/1.0)**(-1.0)  # Vesta

#tmp=0.7; set label sprintf("    %.1f    ", -1.0+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set label "possible\nsecond\nimpacts" at 1.0e2,5.0e6 center font "Helvetica,14" tc 'black'
set arrow from 0.8e2,1.0e5 to 2.0e1,2.0e2 lw 1 lc 'black' front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/1100.out | ./hc.awk" u 1:2 w l lw 2 lc '#00ccff' t "evolved MB",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l ls 4 t "initial Vesta",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/1100.out | ./hc.awk" u 1:2 w l lw 2 lc '#ffaa00' t "evolved Vesta",\
  "../src/4_Vesta_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Vesta",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\


#  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\



